==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Bildbetrachter</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Der Deepin Bildbetrachter ist eine elegante &amp; schnelle Bildverwaltung.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Bildinformationen</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Basisinformationen</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Die Datei enthält mehrere Seiten. Verwenden Sie den Dokumentbetrachter Evince, um alle Seiten einzusehen.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Verzeichnis öffnen</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Sie haben keine Berechtigung zum Betrachten des Bildes</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Bilddatei nicht gefunden</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Änderungsdatum</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Maße</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Aufnahmedatum</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Belichtungsmodus</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Belichtungsprogramm</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Belichtungszeit</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blitz</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Blende</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Brennweite</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Max. Blendenöffnung</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Messmethode</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Weißabgleich</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Blitzbelichtungskorrektur</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Linsenmodell</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Farbraum</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameramodell</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Abmessungen</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Schlagwort</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Keine Skalierung</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Seite an Bild anpassen</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Bild an Seite anpassen</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Skalieren auf:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Zentimeter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Zoll</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Bildposition</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Skalierung</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Bildeinstellungen</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Bildeinstellungen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Jalousie</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Überdecken</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Wischen</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Oval</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>jjjj/MM/tt HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Neuen Namen eingeben</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Verzeichnis auswählen</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Dieses Verzeichnis wird nicht synchronisiert</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Synchronisierungsverzeichnisverwaltung</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Die Verzeichnisliste ist leer</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Synchronisierung abbrechen</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Das Gerät wurde entfernt</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Dieses Verzeichnis existiert nicht mehr</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Wird berechnet ...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Bildbetrachtung</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diashow beenden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Aus Album entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Als Favorit entfernen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Vorheriger Bildschirm</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Nächster Bildschirm</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tastenkürzel anzeigen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Vollbild beenden</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Hineinzoomen</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Herauszoomen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Bitte geben Sie ein neues Tastenkürzel ein</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Bild anzeigen</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Standardeinstellungen wiederherstellen</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diashow beenden</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Aus Album entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Als Favorit entfernen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Präsentationseinstellungen</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Übergangseffekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Übergangsdauer</translation>
    </message>
    <message>
        <source>second</source>
        <translation>Sekunde</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Mein Favorit</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Größe</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>An Fenster anpassen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Bildverwaltung</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mein Favorit</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Größe</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>An Fenstergröße anpassen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Favorit entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit hinzufügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Keine Bilddateien gefunden</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Bilddatei nicht gefunden</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Animationseinstellungen</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Effekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Zeitleiste</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Zu Album hinzufügen</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Zu neuem Album hinzufügen</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Vollbild beenden</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Aus Album entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Als Favorit entfernen</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Navigationsfenster anzeigen</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Navigationsfenster ausblenden</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Alle Bilder</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Zeichnen</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.3.orig.tar.xz: deepin-image-viewer-5.9.3/src/translations/deepin-image-viewer_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Bilddatei nicht gefunden</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Bildbetrachtung</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Vollbild beenden</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Text extrahieren</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformationen</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Hineinzoomen</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Herauszoomen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tastenkürzel anzeigen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Bildbetrachter</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Der Deepin Bildbetrachter ist eine elegante &amp; schnelle Bildverwaltung.</translation>
    </message>
</context>
</TS>
